@@ -7,7 +7,7 @@ import pandas as pd
 import scanpy as sc
 import matplotlib.pyplot as plt
 
-matcher.orthologMapper()
+#matcher.orthologMapper()
 # print("Reading patterns...", file=sys.stderr)
 patterns = sc.read_h5ad('patterns_anndata.h5ad')
 print(patterns.X.shape, "patterns shape")
@@ -22,19 +22,26 @@ print(dataset.X.shape, "Target shape")
 
 
 dataset_filtered, patterns_filtered = matcher.filterAnnDatas(dataset, patterns, 'gene_id')
-dataset_filtered, patterns_filtered = matcher.logTransform(dataset_filtered)
+#dataset_filtered, patterns_filtered = matcher.logTransform(dataset_filtered)
 
 # stats.geneSelectivity(patterns_filtered, 'ENSMUSG00000036887', 24)
 # projection_object.geneSelectivity(patterns_filtered, 'ENSMUSG00000036905', 5)
 # projection_object.geneSelectivity(patterns_filtered, 'ENSMUSG00000036896', 6)
-rg.NNLR_ElasticNet(dataset_filtered, patterns_filtered, 'retinaProject', .01, .001, layer='log')
+rg.NNLR_ElasticNet(dataset_filtered, patterns_filtered, 'retinaProject', .01, .001)
 # stats.geneDriver(dataset_filtered, patterns_filtered, 'ENSMUSG00000036896', "CellType", "Brain Fibroblasts", "retinaProject")
+microglia  = dataset_filtered[dataset_filtered.obs['CellType'].isin(['Microglia'])]
+print(microglia.shape)
+C1 = microglia[microglia.obsm['retinaProject'][:, 4] > 1]
+C2 = microglia[microglia.obsm['retinaProject'][:, 4] <1]
+print(C1.shape)
+print(C2.shape)
+stats.HotellingT2(C1, C2)
 
 # projection_object.NNLR_positive_Lasso(dataset_filtered, patterns_filtered, 'retinaProject', 0.005)
 # projection_object.NNLR_LeastSquares(dataset_filtered, patterns_filtered, 'retinaProject')
 # viz.pearsonMatrix(dataset_filtered, patterns_filtered, 'CellType', 12, 'retinaProject', 'PearsonRetina',
 #                 True, row_cluster=True)
 print("pearson")
-viz.UMAP_Projection(dataset_filtered, 'CellType', 'retinaProject', 'retinaUMAP', 20)
+#viz.UMAP_Projection(dataset_filtered, 'CellType', 'retinaProject', 'retinaUMAP', 10)
 # stats.featureImportance(dataset_filtered, 80, 'retinaProject')
-# viz.featurePlots(dataset_filtered, [21], 'retinaProject', 'retinaUMAP')
+#viz.featurePlots(dataset_filtered, [9], 'retinaProject', 'retinaUMAP')
